#! /usr/bin/env python3

import unittest

from __init__ import activate, get_language, get_lazy_text, get_text, init_texere, switch_language


class TestSequenceFunctions(unittest.TestCase):

    def setUp(self):
        init_texere('test_data', 'de')

    def test_get_language00(self):
        self.assertEqual(get_language(), 'de')

    def test_get_key(self):
        self.assertEqual(get_text('key'), '123')

    def test_get_key_fail(self):
        self.assertEqual(get_text('key_not_there'), None)

    def test_lazy_text(self):
        lazy = get_lazy_text('key')
        activate('en')
        self.assertEqual(str(lazy), '123en')

    def test_context_switch(self):
        self.assertEqual(get_language(), 'de')
        with switch_language('en'):
            self.assertEqual(get_language(), 'en')
            self.assertEqual(get_text('key'), '123en')
        self.assertEqual(get_language(), 'de')

    @switch_language('en')
    def test_with_decorator(self):
        self.assertEqual(get_language(), 'en')
        self.assertEqual(get_text('key'), '123en')


if __name__ == '__main__':
    unittest.main()
